summaryrefslogtreecommitdiff
path: root/jstests/sharding/rename.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/sharding/rename.js')
-rw-r--r--jstests/sharding/rename.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/sharding/rename.js b/jstests/sharding/rename.js
index 1588d1eb3a6..ba82e88fa2b 100644
--- a/jstests/sharding/rename.js
+++ b/jstests/sharding/rename.js
@@ -75,12 +75,12 @@ jsTest.log("Testing write concern (2)");
// Kill any node. Don't care if it's a primary or secondary.
replTest.stop(0);
// Call getPrimary() to populate replTest._slaves.
replTest.getPrimary();
-let liveSlaves = replTest._slaves.filter(function(node) {
+let liveSecondaries = replTest.getSecondaries().filter(function(node) {
return node.host !== replTest.nodes[0].host;
});
-replTest.awaitSecondaryNodes(null, liveSlaves);
+replTest.awaitSecondaryNodes(null, liveSecondaries);
awaitRSClientHosts(s.s, replTest.getPrimary(), {ok: true, ismaster: true}, replTest.name);
assert.commandWorked(db.foo.insert({_id: 4}));
@@ -75,12 +75,12 @@ jsTest.log("Testing write concern (2)");
// Kill any node. Don't care if it's a primary or secondary.
replTest.stop(0);
-// Call getPrimary() to populate replTest._slaves.
+// Call getPrimary() to populate replTest._secondaries.
replTest.getPrimary();